@@ -6,7 +6,7 @@
 #' @param X object of class 'extended_selection_table' (see \code{\link{selection_table}}).
 #' @param samp.rate Numeric vector of length 1 with the sampling rate (in kHz) for output files. Default is \code{NULL}.
 #' @param bit.depth Numeric vector of length 1 with the dynamic interval (i.e. bit depth) for output files.
-# #' @param sox Logical to control whether \href{http://sox.sourceforge.net/sox.html}{SOX} is used internally for resampling. Sox must be installed. Default is \code{FALSE}. \href{http://sox.sourceforge.net/sox.html}{SOX} is a better option if having aliasing issues after resampling.
+# #' @param sox Logical to control whether \href{https://sox.sourceforge.net/sox.html}{SOX} is used internally for resampling. Sox must be installed. Default is \code{FALSE}. \href{https://sox.sourceforge.net/sox.html}{SOX} is a better option if having aliasing issues after resampling.
 #' @param avoid.clip Logical to control whether the volume is automatically 
 #' adjusted to avoid clipping high amplitude samples when resampling. Ignored if
 #'  '\code{sox = FALSE}. Default is \code{TRUE}.
@@ -18,7 +18,7 @@
 #' @name resample_est
 #' @details This function aims to simplify the process of homogenizing sound 
 #' files (sampling rate and bit depth). This is a necessary step before running 
-#' any further (bio)acoustic analysis. \href{http://sox.sourceforge.net/sox.html}{SOX} must be installed.
+#' any further (bio)acoustic analysis. \href{https://sox.sourceforge.net/sox.html}{SOX} must be installed.
 #' @examples
 #' \dontrun{
 #' data(list = c("Phae.long1", "Phae.long2", "Phae.long3", "Phae.long4", "selec_table"))
@@ -47,26 +47,20 @@ resample_est <- function(X, samp.rate = 44.1, bit.depth = 16, avoid.clip = TRUE,
   
   # error message if bioacoustics is not installed
   # if (!requireNamespace("bioacoustics",quietly = TRUE) & !sox)
-  #   stop("must install 'bioacoustics' to use mp32wav() when 'sox = FALSE'")
+  #   stop2("must install 'bioacoustics' to use mp32wav() when 'sox = FALSE'")
 
   #check bit.depth
-  if (length(bit.depth) >1) stop("'bit.depth' should have a single value")
+  if (length(bit.depth) >1) stop2("'bit.depth' should have a single value")
     bit.depth <- as.character(bit.depth)
-    if (!bit.depth %in% c("1", "8", "16", "24", "32", "64", "0")) stop('only this "bit.depth" values allowed c("1", "8", "16", "24", "32", "64", "0") \n see ?tuneR::normalize')
-  
-  # set pb options 
-  on.exit(pbapply::pboptions(type = .Options$pboptions$type), add = TRUE)
-  
+    if (!bit.depth %in% c("1", "8", "16", "24", "32", "64", "0")) stop2('only this "bit.depth" values allowed c("1", "8", "16", "24", "32", "64", "0") \n see ?tuneR::normalize')
+
   #### set arguments from options
   # get function arguments
-  argms <- methods::formalArgs(mp32wav)
+  argms <- methods::formalArgs(resample_est)
   
   # get warbleR options
   opt.argms <- if(!is.null(getOption("warbleR"))) getOption("warbleR") else SILLYNAME <- 0
   
-  # rename path for sound files
-  names(opt.argms)[names(opt.argms) == "wav.path"] <- "path"
-  
   # remove options not as default in call and not in function arguments
   opt.argms <- opt.argms[!sapply(opt.argms, is.null) & names(opt.argms) %in% argms]
   
@@ -81,15 +75,15 @@ resample_est <- function(X, samp.rate = 44.1, bit.depth = 16, avoid.clip = TRUE,
     for (q in 1:length(opt.argms))
       assign(names(opt.argms)[q], opt.argms[[q]])
   
-  # set pb options 
-  pbapply::pboptions(type = ifelse(pb, "timer", "none"))
+  
+  
   
   # set clusters for windows OS and no soz
   if (Sys.info()[1] == "Windows" & parallel > 1)
     cl <- parallel::makePSOCKcluster(getOption("cl.cores", parallel)) else cl <- parallel
   
   # if (!sox)
-  #   out <- pbapply::pblapply(attributes(X)$wave.objects, cl = cl, function(x)
+  #   out <- pblapply_wrblr_int(pbar = pb, X = attributes(X)$wave.objects, cl = cl, function(x)
   # {
   # 
   #   if (x@samp.rate != samp.rate * 1000) {
@@ -110,7 +104,7 @@ resample_est <- function(X, samp.rate = 44.1, bit.depth = 16, avoid.clip = TRUE,
   #   }) else {
   #    
       
-      out <- pbapply::pblapply(attributes(X)$wave.objects, function(x){
+      out <- pblapply_wrblr_int(pbar = pb, X = attributes(X)$wave.objects, FUN = function(x){
         
         # fo saving current wave    
         tempfile <- paste0(tempfile(), ".wav")
@@ -118,7 +112,7 @@ resample_est <- function(X, samp.rate = 44.1, bit.depth = 16, avoid.clip = TRUE,
         # for writting converted wave
         tempfile2 <- paste0(tempfile(), ".wav")
         
-        suppressWarnings(tuneR::writeWave(extensible = FALSE, object = tuneR::normalize(x), filename = tempfile))
+        suppressWarnings(tuneR::writeWave(extensible = FALSE, object = tuneR::normalize(x, unit = bit.depth), filename = tempfile))
    
         cll <- paste0("sox '", tempfile,"'  -t wavpcm ", "-b ", bit.depth, " '", tempfile2, "' rate ", samp.rate * 1000, " dither -s") 
         
@@ -130,7 +124,7 @@ resample_est <- function(X, samp.rate = 44.1, bit.depth = 16, avoid.clip = TRUE,
         
         out <- suppressWarnings(system(cll, ignore.stdout = FALSE, intern = TRUE)) 
         
-        x <- warbleR::read_wave(X = basename(tempfile2), path = tempdir())
+        x <- warbleR::read_sound_file(X = basename(tempfile2), path = tempdir())
         
         # remove files
         unlink(c(tempfile, tempfile2))  
@@ -147,7 +141,6 @@ resample_est <- function(X, samp.rate = 44.1, bit.depth = 16, avoid.clip = TRUE,
   # fix attributes
   attributes(X)$check.results$sample.rate <- samp.rate
   attributes(X)$check.results$bits <- bit.depth
-  # attributes(X)$check.results$n.samples <- sapply(attributes(X)$check.results$sound.files, function(x) length(x@left)) 
   attributes(X)$check.results$n.samples <- sapply(X$sound.files, function(x) length(attributes(X)$wave.objects[[which(names(attributes(X)$wave.objects) == x)]]@left)) 
   
   if (any(X$top.freq > samp.rate / 2)) 
@@ -159,3 +152,12 @@ resample_est <- function(X, samp.rate = 44.1, bit.depth = 16, avoid.clip = TRUE,
   
   return(X)
 }
+
+##############################################################################################################
+#' alternative name for \code{\link{resample_est}}
+#'
+#' @keywords internal
+#' @details see \code{\link{resample_est}} for documentation. \code{\link{resample_est_waves}} will be deprecated in future versions.
+#' @export
+
+resample_est_waves <- resample_est
